==> eam-wshub-proxyclient-11.5-10-sources.jar: net/datastream/schemas/mp_entities/screendataspy_001/ScreenDataspy.java <==

package net.datastream.schemas.mp_entities.screendataspy_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.SCREENDATASPYID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENDATASPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATASPYDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABTEXTDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POPUPDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULT" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "screendataspyid",
    "dataspydescription",
    "tabtextdescription",
    "userid",
    "usergroupid",
    "popupdescription",
    "_default"
})
@XmlRootElement(name = "ScreenDataspy")
public class ScreenDataspy {

    @XmlElement(name = "SCREENDATASPYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected SCREENDATASPYID_Type screendataspyid;
    @XmlElement(name = "DATASPYDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dataspydescription;
    @XmlElement(name = "TABTEXTDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String tabtextdescription;
    @XmlElement(name = "USERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type userid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "POPUPDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String popupdescription;
    @XmlElement(name = "DEFAULT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String _default;

    /**
     * Obtient la valeur de la propriété screendataspyid.
     * 
     * @return
     *     possible object is
     *     {@link SCREENDATASPYID_Type }
     *     
     */
    public SCREENDATASPYID_Type getSCREENDATASPYID() {
        return screendataspyid;
    }

    /**
     * Définit la valeur de la propriété screendataspyid.
     * 
     * @param value
     *     allowed object is
     *     {@link SCREENDATASPYID_Type }
     *     
     */
    public void setSCREENDATASPYID(SCREENDATASPYID_Type value) {
        this.screendataspyid = value;
    }

    /**
     * Obtient la valeur de la propriété dataspydescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATASPYDESCRIPTION() {
        return dataspydescription;
    }

    /**
     * Définit la valeur de la propriété dataspydescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATASPYDESCRIPTION(String value) {
        this.dataspydescription = value;
    }

    /**
     * Obtient la valeur de la propriété tabtextdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABTEXTDESCRIPTION() {
        return tabtextdescription;
    }

    /**
     * Définit la valeur de la propriété tabtextdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABTEXTDESCRIPTION(String value) {
        this.tabtextdescription = value;
    }

    /**
     * Obtient la valeur de la propriété userid.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Définit la valeur de la propriété userid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Obtient la valeur de la propriété usergroupid.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Définit la valeur de la propriété usergroupid.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Obtient la valeur de la propriété popupdescription.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPOPUPDESCRIPTION() {
        return popupdescription;
    }

    /**
     * Définit la valeur de la propriété popupdescription.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPOPUPDESCRIPTION(String value) {
        this.popupdescription = value;
    }

    /**
     * Obtient la valeur de la propriété default.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEFAULT() {
        return _default;
    }

    /**
     * Définit la valeur de la propriété default.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEFAULT(String value) {
        this._default = value;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/screendataspy_001/ScreenDataspy.java <==

package net.datastream.schemas.mp_entities.screendataspy_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.SCREENDATASPYID_Type;
import net.datastream.schemas.mp_fields.USERGROUPID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SCREENDATASPYID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DATASPYDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TABTEXTDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}USERGROUPID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}POPUPDESCRIPTION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}DEFAULT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOWDATASPYEDIT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOWGLOBALDATASPYCONFIGURATION" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ALLOWDATASPYADVANCEDFILTERS" minOccurs="0"/>
 *         &lt;element name="GLOBALGROUPDATASPY" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "screendataspyid",
    "dataspydescription",
    "tabtextdescription",
    "userid",
    "usergroupid",
    "popupdescription",
    "_default",
    "allowdataspyedit",
    "allowglobaldataspyconfiguration",
    "allowdataspyadvancedfilters",
    "globalgroupdataspy"
})
@XmlRootElement(name = "ScreenDataspy")
public class ScreenDataspy {

    @XmlElement(name = "SCREENDATASPYID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected SCREENDATASPYID_Type screendataspyid;
    @XmlElement(name = "DATASPYDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String dataspydescription;
    @XmlElement(name = "TABTEXTDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String tabtextdescription;
    @XmlElement(name = "USERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type userid;
    @XmlElement(name = "USERGROUPID", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERGROUPID_Type usergroupid;
    @XmlElement(name = "POPUPDESCRIPTION", namespace = "http://schemas.datastream.net/MP_fields")
    protected String popupdescription;
    @XmlElement(name = "DEFAULT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String _default;
    @XmlElement(name = "ALLOWDATASPYEDIT", namespace = "http://schemas.datastream.net/MP_fields")
    protected String allowdataspyedit;
    @XmlElement(name = "ALLOWGLOBALDATASPYCONFIGURATION", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String allowglobaldataspyconfiguration;
    @XmlElement(name = "ALLOWDATASPYADVANCEDFILTERS", namespace = "http://schemas.datastream.net/MP_fields")
    protected String allowdataspyadvancedfilters;
    @XmlElement(name = "GLOBALGROUPDATASPY")
    protected String globalgroupdataspy;

    /**
     * Gets the value of the screendataspyid property.
     * 
     * @return
     *     possible object is
     *     {@link SCREENDATASPYID_Type }
     *     
     */
    public SCREENDATASPYID_Type getSCREENDATASPYID() {
        return screendataspyid;
    }

    /**
     * Sets the value of the screendataspyid property.
     * 
     * @param value
     *     allowed object is
     *     {@link SCREENDATASPYID_Type }
     *     
     */
    public void setSCREENDATASPYID(SCREENDATASPYID_Type value) {
        this.screendataspyid = value;
    }

    /**
     * Gets the value of the dataspydescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDATASPYDESCRIPTION() {
        return dataspydescription;
    }

    /**
     * Sets the value of the dataspydescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDATASPYDESCRIPTION(String value) {
        this.dataspydescription = value;
    }

    /**
     * Gets the value of the tabtextdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTABTEXTDESCRIPTION() {
        return tabtextdescription;
    }

    /**
     * Sets the value of the tabtextdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTABTEXTDESCRIPTION(String value) {
        this.tabtextdescription = value;
    }

    /**
     * Gets the value of the userid property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getUSERID() {
        return userid;
    }

    /**
     * Sets the value of the userid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setUSERID(USERID_Type value) {
        this.userid = value;
    }

    /**
     * Gets the value of the usergroupid property.
     * 
     * @return
     *     possible object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public USERGROUPID_Type getUSERGROUPID() {
        return usergroupid;
    }

    /**
     * Sets the value of the usergroupid property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERGROUPID_Type }
     *     
     */
    public void setUSERGROUPID(USERGROUPID_Type value) {
        this.usergroupid = value;
    }

    /**
     * Gets the value of the popupdescription property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPOPUPDESCRIPTION() {
        return popupdescription;
    }

    /**
     * Sets the value of the popupdescription property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPOPUPDESCRIPTION(String value) {
        this.popupdescription = value;
    }

    /**
     * Gets the value of the default property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getDEFAULT() {
        return _default;
    }

    /**
     * Sets the value of the default property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setDEFAULT(String value) {
        this._default = value;
    }

    /**
     * Gets the value of the allowdataspyedit property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLOWDATASPYEDIT() {
        return allowdataspyedit;
    }

    /**
     * Sets the value of the allowdataspyedit property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLOWDATASPYEDIT(String value) {
        this.allowdataspyedit = value;
    }

    /**
     * Gets the value of the allowglobaldataspyconfiguration property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLOWGLOBALDATASPYCONFIGURATION() {
        return allowglobaldataspyconfiguration;
    }

    /**
     * Sets the value of the allowglobaldataspyconfiguration property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLOWGLOBALDATASPYCONFIGURATION(String value) {
        this.allowglobaldataspyconfiguration = value;
    }

    /**
     * Gets the value of the allowdataspyadvancedfilters property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getALLOWDATASPYADVANCEDFILTERS() {
        return allowdataspyadvancedfilters;
    }

    /**
     * Sets the value of the allowdataspyadvancedfilters property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setALLOWDATASPYADVANCEDFILTERS(String value) {
        this.allowdataspyadvancedfilters = value;
    }

    /**
     * Gets the value of the globalgroupdataspy property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getGLOBALGROUPDATASPY() {
        return globalgroupdataspy;
    }

    /**
     * Sets the value of the globalgroupdataspy property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setGLOBALGROUPDATASPY(String value) {
        this.globalgroupdataspy = value;
    }

}
